# octadocs

[![Build Status](https://travis-ci.com/anatoly-scherbakov/octadocs.svg?branch=master)](https://travis-ci.com/anatoly-scherbakov/octadocs)
[![Coverage](https://coveralls.io/repos/github/anatoly-scherbakov/octadocs/badge.svg?branch=master)](https://coveralls.io/github/anatoly-scherbakov/octadocs?branch=master)
[![Python Version](https://img.shields.io/pypi/pyversions/octadocs.svg)](https://pypi.org/project/octadocs/)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)

## Features

- Fully typed with annotations and checked with mypy, [PEP561 compatible](https://www.python.org/dev/peps/pep-0561/)
- Add yours!


## Installation

```bash
pip install octadocs
```

## License

[MIT](https://github.com/anatoly-scherbakov/octadocs/blob/master/LICENSE)


## Credits

This project was generated with [`wemake-python-package`](https://github.com/wemake-services/wemake-python-package). Current template version is: [868260c2d659e455bafc2ed4fe242413ef39e4dc](https://github.com/wemake-services/wemake-python-package/tree/868260c2d659e455bafc2ed4fe242413ef39e4dc). See what is [updated](https://github.com/wemake-services/wemake-python-package/compare/868260c2d659e455bafc2ed4fe242413ef39e4dc...master) since then.
